@@ -35,38 +35,44 @@
 # Property cycles
 # ---------------
 #
-# It is often desirable to use different `property cycles
+# It is often useful to create on-the-fly `property cycles
 # <https://matplotlib.org/tutorials/intermediate/color_cycle.html#sphx-glr-tutorials-intermediate-color-cycle-py>`__
-# for different axes or different plot elements. To enable this, the
-# `~proplot.axes.cycle_changer` adds the `cycle` and `cycle_kw` to the 1D
-# plotting methods. These arguments are passed to the
-# `~proplot.constructor.Cycle` constructor function, and the resulting property
-# cycle is used to style the input data. ProPlot iterates through property
-# cycle properties when (1) making multiple calls to a plotting command, or (2)
-# plotting successive columns of 2-dimensional input data. For more information
-# on property cycles, see the :ref:`color cycles section <ug_cycles>` and `this
-# matplotlib tutorial
+# and use different property cycles for different plot elements. You can create and
+# apply property cycles on-the-fly using the `cycle` and `cycle_kw` arguments, available
+# with any plotting method wrapped by `~proplot.axes.cycle_changer`. `cycle` and
+# `cycle_kw` are passed to the `~proplot.constructor.Cycle` constructor function, and
+# the resulting property cycle is used for the plot. You can specify `cycle`
+# once with 2D input data (in which case each column is plotted in succession
+# according to the property cycle) or call a plotting command multiple times with the
+# same `cycle` argument each time (the property cycle is not reset). For more
+# information on property cycles, see the :ref:`color cycles section <ug_cycles>` and
+# `this matplotlib tutorial
 # <https://matplotlib.org/tutorials/intermediate/color_cycle.html#sphx-glr-tutorials-intermediate-color-cycle-py>`__.
 
 # %%
 import proplot as plot
 import numpy as np
+N = 4
 state = np.random.RandomState(51423)
-data1 = state.rand(6, 4)
-data2 = state.rand(6, 4) * 1.5
+data1 = state.rand(6, N)
+data2 = state.rand(6, N) * 1.5
 with plot.rc.context({'lines.linewidth': 3}):
     fig, axs = plot.subplots(ncols=2)
     axs.format(xlabel='xlabel', ylabel='ylabel', suptitle='Local property cycles demo')
 
-    # Property cycles specific to datasets
-    axs[0].plot(data1, cycle='Reds', cycle_kw={'left': 0.3})
-    axs[0].plot(data2, cycle='Blues', cycle_kw={'left': 0.3})
-    axs[1].plot(
+    # Use property cycle for columns of 2D input data
+    axs[0].plot(
         data1 * data2,
         cycle='black',
         cycle_kw={'linestyle': ('-', '--', '-.', ':')}
     )
 
+    # Use property cycle with successive plot() calls
+    for i in range(data1.shape[1]):
+        axs[1].plot(data1[:, i], cycle='Reds', cycle_kw={'N': N, 'left': 0.3})
+    for i in range(data1.shape[1]):
+        axs[1].plot(data2[:, i], cycle='Blues', cycle_kw={'N': N, 'left': 0.3})
+
 
 # %% [raw] raw_mimetype="text/restructuredtext"
 # .. _ug_1dstd:
@@ -74,7 +80,7 @@ with plot.rc.context({'lines.linewidth': 3}):
 # Standardized arguments
 # ----------------------
 #
-# The `~proplot.axes.standardize_1d` wrapper is used to standardize
+# The `~proplot.axes.standardize_1d` wrapper standardizes
 # positional arguments across all 1D plotting methods.
 # `~proplot.axes.standardize_1d` allows you to optionally omit *x*
 # coordinates, in which case they are inferred from the data. It also permits
@@ -234,7 +240,7 @@ ax = axs[1]
 ax.scatter(
     data,
     color='denim', marker='x', markersize=8**2, linewidth=0.8,
-    means=True, shadestds=(-1, 1), legend='ll',
+    means=True, shadestds=(-1, 1), shadelabel=True, legend='ll',
 )
 ax.format(title='Scatter plot')
 
