@@ -200,6 +200,7 @@ _rc_matplotlib_default = {
     'legend.handletextpad': 0.5,
     'mathtext.fontset': 'custom',
     'mathtext.default': 'regular',
+    'patch.linewidth': LINEWIDTH,
     'savefig.bbox': None,  # use custom tight layout
     'savefig.directory': '',  # current directory
     'savefig.dpi': 1200,  # academic journal recommendations for raster line art
@@ -284,15 +285,21 @@ _rc_proplot = {
         'bold',
         'a-b-c label font weight.'
     ),
+    'autoformat': (
+        True,
+        'Whether to automatically apply labels from `pandas.Series`, '
+        '`pandas.DataFrame`, and `xarray.DataArray` objects passed to '
+        'plotting functions.'
+    ),
 
     # Axes additions
     'alpha': (
-        1,
+        1.0,
         'The opacity of the background axes patch.'
     ),
     'axes.alpha': (
         1.0,
-        'Opacity of the background axes patch.'
+        'The opacity of the background axes patch.'
     ),
     'formatter.timerotation': (
         90,
@@ -901,12 +908,11 @@ _rc_children = {
         'rightlabel.size', 'bottomlabel.size'
     ),
     'linewidth': (
-        # also sets minor tick widths through tick.ratio
+        # NOTE: rc_configurator will adjust [xy]tick.minor.width accordingly
         # NOTE: do not add grid.linewidth to this because common use case is
         # making the edge a bit thicker to *highlight* a subplot, and generally
         # we do not want that to affect gridlines.
-        'axes.linewidth', 'hatch.linewidth',
-        'xtick.major.width', 'ytick.major.width'
+        'axes.linewidth', 'xtick.major.width', 'ytick.major.width'
     ),
     'margin': (
         'axes.xmargin', 'axes.ymargin'
